@@ -82,7 +82,7 @@ def SegmentTile(tile, background, pin_size=25, threshold_method='otsu'):
         centers = [None]*len(hough_radii) 
         accums = [None]*len(hough_radii) 
         radii = [None]*len(hough_radii)
-        for radius, h in zip(hough_radii, hough_res):
+        for i, (radius, h) in enumerate(zip(hough_radii, hough_res)):
             # For each radius, extract one circle
             peaks = peak_local_max(h, num_peaks=1, min_distance=25)
             centers[i] = peaks.tolist()[0]
